==> primordial_harvest-fabric-1.21.1-21.1.4-sources.jar: net/darkhax/primordialharvest/common/impl/blocks/BloodCauldronBlock.java <==
package net.darkhax.primordialharvest.common.impl.blocks;

import net.darkhax.primordialharvest.common.impl.Content;
import net.darkhax.primordialharvest.common.impl.Helper;
import net.minecraft.class_1297;
import net.minecraft.class_1542;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_2246;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3611;
import net.minecraft.class_5556;
import net.minecraft.class_5620;
import org.jetbrains.annotations.NotNull;

public class BloodCauldronBlock extends class_5556 {

    public BloodCauldronBlock() {
        super(class_1959.class_1963.field_9384, Content.INTERACTIONS, class_2251.method_55226(class_2246.field_10593));
    }

    @Override
    protected boolean method_32765(@NotNull class_3611 fluid) {
        return false;
    }

    @Override
    protected void method_32764(@NotNull class_2680 state, @NotNull class_1937 level, @NotNull class_2338 pos, @NotNull class_3611 fluid) {
        // No-op
    }

    @Override
    protected void method_9548(@NotNull class_2680 state, @NotNull class_1937 level, @NotNull class_2338 pos, @NotNull class_1297 entity) {
        if (!level.field_9236 && entity instanceof class_1542 itemEntity && this.method_31616(state, pos, entity)) {
            final class_5620 interaction = this.field_27084.comp_1982().get(itemEntity.method_6983().method_7909());
            if (interaction != null && interaction.interact(state, level, pos, null, null, itemEntity.method_6983()).method_55643()) {
                Helper.shrink(itemEntity);
                method_31650(state, level, pos);
            }
        }
    }

    @Override
    public void method_9504(@NotNull class_2680 state, @NotNull class_1937 level, @NotNull class_2338 pos, class_1959.@NotNull class_1963 precipitation) {
        // No-op
    }
}

==> primordial_harvest-fabric-1.21.1-21.1.9-sources.jar: net/darkhax/primordialharvest/common/impl/blocks/BloodCauldronBlock.java <==
package net.darkhax.primordialharvest.common.impl.blocks;

import net.darkhax.primordialharvest.common.impl.Content;
import net.darkhax.primordialharvest.common.impl.Helper;
import net.minecraft.class_1297;
import net.minecraft.class_1542;
import net.minecraft.class_1937;
import net.minecraft.class_1959;
import net.minecraft.class_2338;
import net.minecraft.class_2680;
import net.minecraft.class_3611;
import net.minecraft.class_3620;
import net.minecraft.class_5556;
import net.minecraft.class_5620;
import org.jetbrains.annotations.NotNull;

public class BloodCauldronBlock extends class_5556 {

    private static final class_2251 PROPERTIES = class_2251.method_9637().method_31710(class_3620.field_16023).method_29292().method_9632(2.0F).method_22488();

    public BloodCauldronBlock() {
        super(class_1959.class_1963.field_9384, Content.INTERACTIONS, PROPERTIES);
    }

    @Override
    protected boolean method_32765(@NotNull class_3611 fluid) {
        return false;
    }

    @Override
    protected void method_32764(@NotNull class_2680 state, @NotNull class_1937 level, @NotNull class_2338 pos, @NotNull class_3611 fluid) {
        // No-op
    }

    @Override
    protected void method_9548(@NotNull class_2680 state, @NotNull class_1937 level, @NotNull class_2338 pos, @NotNull class_1297 entity) {
        if (!level.field_9236 && entity instanceof class_1542 itemEntity && this.method_31616(state, pos, entity)) {
            final class_5620 interaction = this.field_27084.comp_1982().get(itemEntity.method_6983().method_7909());
            if (interaction != null && interaction.interact(state, level, pos, null, null, itemEntity.method_6983()).method_55643()) {
                Helper.shrink(itemEntity);
                method_31650(state, level, pos);
            }
        }
    }

    @Override
    public void method_9504(@NotNull class_2680 state, @NotNull class_1937 level, @NotNull class_2338 pos, class_1959.@NotNull class_1963 precipitation) {
        // No-op
    }
}
